``ExposoGraph.config``
======================

Runtime configuration helpers for deployment mode selection.

.. autoclass:: ExposoGraph.config.AppMode
   :members:
   :undoc-members:

.. autoclass:: ExposoGraph.config.GraphMode
   :members:
   :undoc-members:

.. autoclass:: ExposoGraph.config.GraphVisibility
   :members:
   :undoc-members:

.. autofunction:: ExposoGraph.config.normalize_app_mode

.. autofunction:: ExposoGraph.config.normalize_graph_mode

.. autofunction:: ExposoGraph.config.normalize_graph_visibility

.. autofunction:: ExposoGraph.config.get_app_mode

.. autofunction:: ExposoGraph.config.persistence_enabled
